@@ -6,8 +6,7 @@ from django import forms
 from django.utils.translation import ugettext_lazy as _
 from django.contrib.auth.models import User, AnonymousUser
 
-#from captcha.fields import CaptchaField
-#from simplemathcaptcha.fields import MathCaptchaField
+from captcha.fields import CaptchaField
 from tendenci.apps.discounts.models import Discount
 from tendenci.core.site_settings.utils import get_setting
 
@@ -22,37 +21,37 @@ class RegAddonForm(forms.Form):
     A RegAddonForm will dynamically add choice fields depending on the
     number of options it has.
     """
-    
+
     def __init__(self, *args, **kwargs):
         self.addons = kwargs.pop('addons')
         self.valid_addons = kwargs.pop('valid_addons', [])
         self.form_index = kwargs.pop('form_index', None)
         self.chosen_addon = None
         super(RegAddonForm, self).__init__(*args, **kwargs)
-        
+
         # initialize addon options and reg_set field
         self.fields['addon'] = forms.ModelChoiceField(
             queryset=self.addons,
             widget=forms.TextInput(attrs={'class': 'addon-input'}))
-        
+
         # dynamically create an option field for each addon
         for addon in self.addons:
             field_name = addon.field_name()
             self.fields[field_name] = forms.ModelChoiceField(
-                label="Options", required=False, empty_label=None,
+                label=_("Options"), required=False, empty_label=None,
                 queryset=addon.options.all(),
                 widget=forms.HiddenInput(attrs={'class': 'option-hidden'}))
-        
+
     def get_form_label(self):
         return self.form_index + 1
-        
+
     def clean_addon(self):
         addon = self.cleaned_data['addon']
         self.chosen_addon = addon
         if addon not in self.valid_addons:
             raise forms.ValidationError(_('Addon is invalid for current set of registrants'))
         return addon
-            
+
     def clean(self):
         """Validate the option fields for the selected addon only"""
         data = self.cleaned_data
@@ -63,7 +62,7 @@ class RegAddonForm(forms.Form):
                 raise forms.ValidationError(_('Option required for %s' % (addon.title)))
 
         return data
-    
+
     def save(self, registration):
         if self.is_valid():
             data = self.cleaned_data
